diff libpurple/protocols/msn/state.h @ 31101:3140627b93e7

Avoid calling xmlnode_from_str twice when parsing the UBX data.
author Elliott Sales de Andrade <qulogic@pidgin.im>
date Wed, 09 Dec 2009 21:32:33 +0000
parents 5913725cbcd6
children 1830fa548302
line wrap: on
line diff
--- a/libpurple/protocols/msn/state.h	Wed Dec 09 21:29:29 2009 +0000
+++ b/libpurple/protocols/msn/state.h	Wed Dec 09 21:32:33 2009 +0000
@@ -64,11 +64,11 @@
 /* Parse CurrentMedia string */
 gboolean msn_parse_currentmedia(const char *cmedia, CurrentMedia *media);
 
-/* Get the CurrentMedia info from the XML string */
-char * msn_get_currentmedia(char *xml_str,gsize len);
+/* Get the CurrentMedia info from the XML node */
+char * msn_get_currentmedia(xmlnode *payloadNode);
 
-/*get the PSM info from the XML string*/
-char * msn_get_psm(char *xml_str,gsize len);
+/* Get the PSM info from the XML node */
+char * msn_get_psm(xmlnode *payloadNode);
 
 MsnAwayType msn_state_from_account(PurpleAccount *account);